package jp.co.sds_corp.syslog.viewer;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyEvent;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.ButtonGroup;
import javax.swing.JCheckBoxMenuItem;
import javax.swing.JFrame;
import javax.swing.JMenu;
import javax.swing.JMenuBar;
import javax.swing.JMenuItem;
import javax.swing.JOptionPane;
import javax.swing.JPopupMenu;
import javax.swing.JRadioButtonMenuItem;
import javax.swing.UIManager;
import javax.swing.WindowConstants;

import jp.co.sds_corp.util.common.CmnProperty;
import jp.co.sds_corp.util.config.IConfigurable;
import jp.co.sds_corp.util.config.IConfiguration;

/**
* SyslogViewerのメインウィンドウです。
*/
public class SyslogWindow extends JFrame implements IConfigurable
{
	private static final long serialVersionUID = 1L;
	SyslogPanel	panel;

	JPopupMenu	popup;
	JMenuBar	menuBar;
	CmnProperty	res;

	public SyslogWindow() {
		super();
		res = new CmnProperty( "resource.viewer" );
		setTitle( "SyslogViewer" );
		setMenu();
		addWindowListener( new WindowAdapter() {
			public void windowClosing( WindowEvent e ) {
				closeWindow();
			}   
		});
		setDefaultCloseOperation( WindowConstants.DO_NOTHING_ON_CLOSE );

		panel = new SyslogPanel();
		getContentPane().add( panel );
	}

	private void closeWindow() {
		String msg = res.getString( "window.close.message" );
		String title = res.getString( "window.close.title" );
		int nRet = JOptionPane.showConfirmDialog( SyslogWindow.this,
					msg, title,
					JOptionPane.YES_NO_OPTION );
		if ( nRet == JOptionPane.YES_OPTION ) {
			System.exit( 0 );
		}
	}

	public void init( IConfiguration config ) throws Exception {
		panel.init( config );
		setBounds( panel.param.getBounds() );
	}

	private void setMenu() {
		JMenu		menu, submenu;
		JMenuItem	menuItem;
		JCheckBoxMenuItem		cbMenuItem;
		JRadioButtonMenuItem	rbMenuItem;
		ButtonGroup group;

		String text;
		menuBar = new JMenuBar();

		// ファイル
		text = res.getString( "menu1.text", null );
		if ( text != null ) {
			menu = new JMenu( text );
			menu.setMnemonic( KeyEvent.VK_F );
			menuBar.add( menu );

			text = res.getString( "menu1.item1.text", null );
			if ( text != null ) {
				menuItem = new JMenuItem( text, KeyEvent.VK_A );
				menuItem.addActionListener( new ActionListener() {
					public void actionPerformed( ActionEvent e ) {
						panel.writeFile( e );
					}
				});
				menu.add( menuItem );
			}

			text = res.getString( "menu1.item2.text", null );
			if ( text != null ) {
				menuItem = new JMenuItem( text, KeyEvent.VK_C );
				menuItem.addActionListener( new ActionListener() {
					public void actionPerformed( ActionEvent e ) {
						panel.clear( e );
					}
				});
				menu.add( menuItem );
			}

			text = res.getString( "menu1.item3.text", null );
			if ( text != null ) {
				menu.addSeparator();
				menuItem = new JMenuItem( text, KeyEvent.VK_S );
				menuItem.addActionListener( new ActionListener() {
					public void actionPerformed( ActionEvent e ) {
						panel.setOption( e );
					}
				});
				menu.add( menuItem );
			}

			text = res.getString( "menu1.item4.text", null );
			if ( text != null ) {
				menuItem = new JMenuItem( text, KeyEvent.VK_V );
				menuItem.addActionListener( new ActionListener() {
					public void actionPerformed( ActionEvent e ) {
						panel.saveOption( e );
					}
				});
				menu.add( menuItem );
			}

			menu.addSeparator();
			text = res.getString( "menu1.item5.text", null );
			if ( text != null ) {
				menuItem = new JMenuItem( text, KeyEvent.VK_X );
				menuItem.addActionListener( new ActionListener() {
					public void actionPerformed( ActionEvent e ) {
						closeWindow();
					}
				});
				menu.add( menuItem );
			}
		}

		// 編集
		text = res.getString( "menu2.text", null );
		if ( text != null ) {
			menu = new JMenu( text );
			menu.setMnemonic( KeyEvent.VK_E );
			menuBar.add( menu );

			text = res.getString( "menu2.item1.text", null );
			if ( text != null ) {
				menuItem = new JMenuItem( text, KeyEvent.VK_D );
				menuItem.addActionListener( new ActionListener() {
					public void actionPerformed( ActionEvent e ) {
						panel.openDesc();
					}
				});
				menu.add( menuItem );
			}

			text = res.getString( "menu2.item2.text", null );
			if ( text != null ) {
				menuItem = new JMenuItem( text, KeyEvent.VK_F );
				menuItem.addActionListener( new ActionListener() {
					public void actionPerformed( ActionEvent e ) {
						panel.search( e );
					}
				});
				menu.add( menuItem );
			}
			menu.addSeparator();

			text = res.getString( "menu2.item3.text", null );
			if ( text != null ) {
				menuItem = new JMenuItem( text, KeyEvent.VK_S );
				menuItem.addActionListener( new ActionListener() {
					public void actionPerformed( ActionEvent e ) {
						panel.statistics( e );
					}
				});
				menu.add( menuItem );
			}
		}

		// 表示
		text = res.getString( "menu3.text", null );
		if ( text != null ) {
			menu = new JMenu( text );
			menu.setMnemonic( KeyEvent.VK_V );
			menuBar.add( menu );

			group = new ButtonGroup();
			text = res.getString( "menu3.item1.text", null );
			if ( text != null ) {
				rbMenuItem = new JRadioButtonMenuItem( text );
				rbMenuItem.addActionListener( new ActionListener() {
					public void actionPerformed( ActionEvent e ) {
						panel.setOrder( e, true );
					}
				});
				rbMenuItem.setSelected( true );
				rbMenuItem.setMnemonic( KeyEvent.VK_N );
				group.add(rbMenuItem);
				menu.add(rbMenuItem);
			}
			text = res.getString( "menu3.item2.text", null );
			if ( text != null ) {
				rbMenuItem = new JRadioButtonMenuItem( text );
				rbMenuItem.addActionListener( new ActionListener() {
					public void actionPerformed( ActionEvent e ) {
						panel.setOrder( e, false );
					}
				});
				rbMenuItem.setMnemonic( KeyEvent.VK_O );
				group.add(rbMenuItem);
				menu.add(rbMenuItem);
			}

			menu.addSeparator();
			text = res.getString( "menu3.item3.text", null );
			if ( text != null ) {
				menuItem = new JMenuItem( text, KeyEvent.VK_F );
				menuItem.addActionListener( new ActionListener() {
					public void actionPerformed( ActionEvent e ) {
						panel.setFont( e );
					}
				});
				menu.add( menuItem );
			}
			text = res.getString( "menu3.item4.text", null );
			if ( text != null ) {
				JMenu subMenu = new JMenu( text );
				subMenu.setMnemonic( KeyEvent.VK_L );
				menu.add( subMenu );
				UIManager.LookAndFeelInfo[] lf = UIManager.getInstalledLookAndFeels();
				for ( int i = 0; i < lf.length; i++ ) {
					menuItem = new JMenuItem( lf[i].getName() );
					menuItem.addActionListener( new ActionListener() {
						public void actionPerformed( ActionEvent e ) {
							panel.setLF( e );
						}
					});
					menuItem.setActionCommand( lf[i].getClassName() );
					subMenu.add( menuItem );
				}
			}
		}

		// ヘルプ
		text = res.getString( "menu4.text", null );
		if ( text != null ) {
			menu = new JMenu( text );
			menu.setMnemonic( KeyEvent.VK_H );
			menuBar.add( menu );
			text = res.getString( "menu4.item1.text", null );
			if ( text != null ) {
				menuItem = new JMenuItem( text, KeyEvent.VK_G );
				menuItem.addActionListener( new ActionListener() {
					public void actionPerformed( ActionEvent e ) {
						System.gc();
					}
				});
				menu.add( menuItem );
			}
			text = res.getString( "menu4.item2.text", null );
			if ( text != null ) {
				menuItem = new JMenuItem( text, KeyEvent.VK_A );
				menuItem.addActionListener( new ActionListener() {
					public void actionPerformed( ActionEvent e ) {
						panel.showHelp( e );
					}
				});
				menu.add( menuItem );
			}
		}

		setJMenuBar( menuBar );
	}

}
