package	jp.co.sds_corp.syslog.action;

import java.io.Serializable;
import java.util.List;

import jp.co.sds_corp.syslog.SyslogEvent;
import jp.co.sds_corp.syslog.filter.IFilter;
import jp.co.sds_corp.syslog.layout.ILayout;
import jp.co.sds_corp.util.config.IConfigSavable;
import jp.co.sds_corp.util.config.IConfigurable;

/**
* アクションを定義するインターフェースです。
*/
public interface IAction extends IConfigurable, IConfigSavable, Serializable
{
	/**
	* アクションを実行します。
	* @param	ev		SyslogEventオブジェクト
	*/
	public void action( SyslogEvent ev );

	/**
	* 設定内容の文字列表現を取得します。
	* @return	設定内容の文字列表現
	*/
	public String paramString();

	/**
	* 設定されているフィルタの一覧を取得します。
	* @return	設定されているフィルタの一覧
	*/
	public List<IFilter> listFilters();

	/**
	* フィルタを追加します。
	* @param	filter	設定するフィルタ
	*/
	public void addFilter( IFilter filter );

	/**
	* フィルタを追加します。
	* @param	list	設定するフィルタの格納されているList
	*/
	public void addFilterList( List<IFilter> list );

	/**
	* フィルタをクリアします。
	*/
	public void clearFilter();

	/**
	* このアクションが有効であるかどうかを返します。
	* @return	このアクションが有効であるかどうか
	*/
	public boolean isValid();

	/**
	* このフィルタの有効であるかどうかを設定します。
	* @param	var		有効フラグ
	*/
	public void setValid( boolean var );

	/**
	* syslogをフォーマットするILayout(layout)を設定します。
	* @param	var		設定するデータ
	*/
	public void setLayout( ILayout var );
	/**
	* syslogをフォーマットするILayout(layout)を取得します。
	* @return	layoutの内容
	*/
	public ILayout getLayout();

}
